# remirepo spec file for php-pecl-handlebars
#
# Copyright (c) 2017-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-handlebars
%endif

%bcond_without     tests

%global pecl_name  handlebars
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
# After 40-psr.ini
%global ini_name   50-%{pecl_name}.ini

%global upstream_version 1.0.0
#global upstream_prever  RC2

Summary:        Handlebars templating language
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        BSD
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.2
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  libhandlebars-devel >= 1.0.0
BuildRequires:  libtalloc-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 8
Recommends:     %{?scl_prefix}php-psr%{?_isa}
%endif

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This extension embeds a Handlebars interpreter into PHP,
allowing the execution of Handlebars templates.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%package devel
Summary:       %{name} developer files (header)
Group:         Development/Libraries
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      %{?scl_prefix}php-devel%{?_isa}

%description devel
These are the files needed to compile programs using %{name}.


%prep
%setup -q -c
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install/register License
%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}


cd NTS
sed -e '/ LDFLAGS=/d;/ CFLAGS=/d;' -i config.m4

# Sanity check, really often broken
extver=$(sed -n '/PHP_HANDLEBARS_VERSION/{s/.* "//;s/".*$//;p}' php_handlebars.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable "%{pecl_name}" extension module
extension=%{pecl_name}.so

; Configuration
;handlebars.pool_size = 0
;handlebars.cache.enable = 1
;handlebars.cache.enable_cli = 0
;handlebars.cache.backend = 'mmap'
;handlebars.cache.max_size = 67108864
;handlebars.cache.max_entries = 349529
;handlebars.cache.max_age = -1
;handlebars.cache.save_path = '/tmp/php-handlebars-cache'
;handlebars.cache.stat = 1
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-handlebars \
    --disable-handlebars-psr \
    --enable-handlebars-ast  \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/php-config

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-handlebars \
    --disable-handlebars-psr \
    --enable-handlebars-ast  \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/zts-php-config

make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Test & Documentation
for i in $(grep 'role="test"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_testdir}/%{pecl_name}/$i
done
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
: Minimal load test for NTS extension
cd NTS
%{__php} --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
OPT="-q -P --show-diff"
%if "%{php_version}" >= "7.4"
OPT="$OPT %{?_smp_mflags}"
%endif

%if "%{php_version}" >= "8.1"
rm ../?TS/tests/handlebars/export/helpers/050.phpt
rm ../?TS/tests/handlebars/export/helpers/051.phpt
rm ../?TS/tests/handlebars/export/helpers/053.phpt
rm ../?TS/tests/handlebars/export/helpers/054.phpt
rm ../?TS/tests/handlebars/export/helpers/055.phpt
rm ../?TS/tests/handlebars/export/helpers/056.phpt
rm ../?TS/tests/handlebars/export/helpers/064.phpt
rm ../?TS/tests/handlebars/export/partials/007.phpt
rm ../?TS/tests/handlebars/export/partials/008.phpt
rm ../?TS/tests/handlebars/export/partials/054.phpt
rm ../?TS/tests/handlebars/export/strict/005.phpt
rm ../?TS/tests/handlebars/export/string-params/001.phpt
rm ../?TS/tests/handlebars/export/string-params/002.phpt
rm ../?TS/tests/handlebars/export/string-params/003.phpt
rm ../?TS/tests/handlebars/export/string-params/004.phpt
rm ../?TS/tests/handlebars/export/string-params/005.phpt
rm ../?TS/tests/handlebars/export/string-params/006.phpt
rm ../?TS/tests/handlebars/export/string-params/007.phpt
rm ../?TS/tests/handlebars/export/string-params/008.phpt
rm ../?TS/tests/handlebars/export/subexpressions/015.phpt
rm ../?TS/tests/handlebars/export/subexpressions/016.phpt
rm ../?TS/tests/handlebars/export/track-ids/002.phpt
rm ../?TS/tests/handlebars/export/track-ids/003.phpt
rm ../?TS/tests/handlebars/export/track-ids/004.phpt
rm ../?TS/tests/handlebars/export/track-ids/005.phpt
rm ../?TS/tests/handlebars/export/track-ids/006.phpt
rm ../?TS/tests/handlebars/export/track-ids/007.phpt
rm ../?TS/tests/handlebars/export/track-ids/008.phpt
rm ../?TS/tests/handlebars/export/track-ids/009.phpt
rm ../?TS/tests/handlebars/export/track-ids/010.phpt
rm ../?TS/tests/handlebars/export/track-ids/011.phpt
rm ../?TS/tests/handlebars/export/track-ids/012.phpt
rm ../?TS/tests/handlebars/export/track-ids/013.phpt
rm ../?TS/tests/handlebars/export/track-ids/014.phpt
rm ../?TS/tests/handlebars/export/track-ids/015.phpt
rm ../?TS/tests/handlebars/export/track-ids/016.phpt
rm ../?TS/tests/handlebars/export/track-ids/017.phpt
%endif

# Upstream test suite
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php $OPT
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
cd ../ZTS
%{__ztsphp} --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
# Upstream test suite
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php $OPT
%endif
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE.md
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%files devel
%doc %{pecl_testdir}/%{pecl_name}
%{php_incldir}/ext/%{pecl_name}

%if %{with_zts}
%{php_ztsincldir}/ext/%{pecl_name}
%endif


%changelog
* Mon Nov 28 2022 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0
- raise dependency on libhandlebars 1.0.0

* Mon Dec  7 2020 Remi Collet <remi@remirepo.net> - 0.9.2-1
- update to 0.9.2

* Sun Apr 19 2020 Remi Collet <remi@remirepo.net> - 0.9.1-1
- update to 0.9.1
- drop patch merged upstream
- skip 1 test with 0.7.1 reported as
  https://github.com/jbboehr/php-handlebars/issues/67

* Fri Apr 17 2020 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0
- raise dependency on PHP 7.2
- fix test suite with PHP 8 using patch from
  https://github.com/jbboehr/php-handlebars/pull/66
- skip 1 test on 32-bit reported as
  https://github.com/jbboehr/php-handlebars/issues/67

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.8.3-2
- rebuild for 7.4.0RC1

* Mon Nov 12 2018 Remi Collet <remi@remirepo.net> - 0.8.3-1
- update to 0.8.3
- raise dependency on PHP 5.6

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.8.2-4
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.8.2-3
- rebuld for 7.3.0alpha4 new ABI

* Tue Jun 26 2018 Remi Collet <remi@remirepo.net> - 0.8.2-2
- add patch for PHP 7.3 from
  https://github.com/jbboehr/php-handlebars/pull/53

* Tue Mar  6 2018 Remi Collet <remi@remirepo.net> - 0.8.2-1
- update to 0.8.2 (stable)
- add optional dependency on psr extension

* Wed Jul 19 2017 Remi Collet <remi@remirepo.net> - 0.8.2~RC2-1
- update to 0.8.2RC2

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.8.2~RC1-3
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 0.8.2~RC1-2
- rebuild for 7.2.0alpha2

* Sun Jun 11 2017 Remi Collet <remi@remirepo.net> - 0.8.2~RC1-1
- ignore minimal PHP version, see
  https://github.com/jbboehr/php-handlebars/pull/44

* Thu Jun  8 2017 Remi Collet <remi@remirepo.net> - 0.8.2~RC1-1
- initial package

